use axum::{
    extract::{Path, State},
    http::HeaderMap,
    routing::{get, post},
    Json, Router,
};

use crate::{
    auth::get_user_from_header,
    model::{member::Roles, User},
    AppState,
};

pub fn routes() -> Router<AppState> {
    Router::new()
        .route("/user", get(get_current_user))
        .route("/user/{user_id}/members", post(members_insert))
}

pub async fn get_current_user(
    State(state): State<AppState>,
    headers: HeaderMap,
) -> Result<Json<User>, crate::Error> {
    let user = get_user_from_header(&state.pool, &headers).await?;
    Ok(Json(user))
}

pub async fn members_insert(
    State(state): State<AppState>,
    Path(user_id): Path<String>,
    headers: HeaderMap,
) -> Result<(), crate::Error> {
    let user = get_user_from_header(&state.pool, &headers).await?;
    user.authorize(&state.pool, Some(Roles::ADMIN), Some(user_id))
        .await?;

    Ok(())
}
